@@ -113,7 +113,7 @@ _cairo_traps_fini (cairo_traps_t *traps)
     if (traps->traps != traps->traps_embedded)
 	free (traps->traps);
 
-    VG (VALGRIND_MAKE_MEM_NOACCESS (traps, sizeof (cairo_traps_t)));
+    VG (VALGRIND_MAKE_MEM_UNDEFINED (traps, sizeof (cairo_traps_t)));
 }
 
 /* make room for at least one more trap */
@@ -284,7 +284,7 @@ _cairo_traps_tessellate_convex_quad (cairo_traps_t *traps,
      * cases to tessellate.
      *
      * First, we have to determine the Y-axis sort of the four
-     * vertices, (either abcd or abdc). After that we need to detemine
+     * vertices, (either abcd or abdc). After that we need to determine
      * which edges will be "left" and which will be "right" in the
      * resulting trapezoids. This can be determined by computing a
      * slope comparison of ab and ad to determine if b is left of d or
